@@ -27,13 +27,13 @@ Copyright 1987, 1988 by Digital Equipment Corporation, Maynard, Massachusetts.
 
                         All Rights Reserved
 
-Permission to use, copy, modify, and distribute this software and its 
-documentation for any purpose and without fee is hereby granted, 
+Permission to use, copy, modify, and distribute this software and its
+documentation for any purpose and without fee is hereby granted,
 provided that the above copyright notice appear in all copies and that
-both that copyright notice and this permission notice appear in 
+both that copyright notice and this permission notice appear in
 supporting documentation, and that the name of Digital not be
 used in advertising or publicity pertaining to distribution of the
-software without specific, written prior permission.  
+software without specific, written prior permission.
 
 DIGITAL DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
 ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL
@@ -54,7 +54,7 @@ SOFTWARE.
 #include <X11/Xmu/Misc.h>
 #include <X11/Xaw/AsciiText.h>
 #include <X11/Xaw/Cardinals.h>
-#include <X11/Xaw/Command.h>	
+#include <X11/Xaw/Command.h>
 #include <X11/Xaw/Label.h>
 #include <X11/Xaw/DialogP.h>
 #include <X11/Xaw/XawInit.h>
@@ -174,6 +174,9 @@ DialogClassRec dialogClassRec = {
   /* form */
   {
     XtInheritLayout,			/* layout */
+#ifndef OLDXAW
+    NULL,
+#endif
   },
   /* dialog */
   {
@@ -188,8 +191,8 @@ WidgetClass dialogWidgetClass = (WidgetClass)&dialogClassRec;
  */
 /*ARGSUSED*/
 static void
-XawDialogInitialize(Widget request, Widget cnew,
-		    ArgList args, Cardinal *num_args)
+XawDialogInitialize(Widget request _X_UNUSED, Widget cnew,
+		    ArgList args _X_UNUSED, Cardinal *num_args _X_UNUSED)
 {
     DialogWidget dw = (DialogWidget)cnew;
     Arg arglist[9];
@@ -220,7 +223,7 @@ XawDialogInitialize(Widget request, Widget cnew,
 	XtSetArg(arglist[0], XtNheight, XtHeight(dw->dialog.iconW));
 	XtSetValues(dw->dialog.labelW, arglist, 1);
     }
-    if (dw->dialog.value != NULL) 
+    if (dw->dialog.value != NULL)
 	CreateDialogValueWidget((Widget)dw);
     else
         dw->dialog.valueW = NULL;
@@ -228,8 +231,8 @@ XawDialogInitialize(Widget request, Widget cnew,
 
 /*ARGSUSED*/
 static void
-XawDialogConstraintInitialize(Widget request, Widget cnew,
-			      ArgList args, Cardinal *num_args)
+XawDialogConstraintInitialize(Widget request _X_UNUSED, Widget cnew,
+			      ArgList args _X_UNUSED, Cardinal *num_args _X_UNUSED)
 {
     DialogWidget dw = (DialogWidget)cnew->core.parent;
     DialogConstraints constraint = (DialogConstraints)cnew->core.constraints;
@@ -238,7 +241,7 @@ XawDialogConstraintInitialize(Widget request, Widget cnew,
 	return;					 /* then just use defaults */
 
     constraint->form.left = constraint->form.right = XtChainLeft;
-    if (dw->dialog.valueW == NULL) 
+    if (dw->dialog.valueW == NULL)
 	constraint->form.vert_base = dw->dialog.labelW;
     else
 	constraint->form.vert_base = dw->dialog.valueW;
@@ -265,13 +268,12 @@ XawDialogConstraintInitialize(Widget request, Widget cnew,
 #define NUM_CHECKS 2
 /*ARGSUSED*/
 static Boolean
-XawDialogSetValues(Widget current, Widget request, Widget cnew,
+XawDialogSetValues(Widget current, Widget request _X_UNUSED, Widget cnew,
 		   ArgList in_args, Cardinal *in_num_args)
 {
     DialogWidget w = (DialogWidget)cnew;
     DialogWidget old = (DialogWidget)current;
     Arg args[5];
-    Cardinal num_args;
     unsigned int i;
     Bool checks[NUM_CHECKS];
 
@@ -310,7 +312,8 @@ XawDialogSetValues(Widget current, Widget request, Widget cnew,
     }
 
     if (checks[LABEL]) {
-	num_args = 0;
+	Cardinal num_args = 0;
+
 	XtSetArg(args[num_args], XtNlabel, w->dialog.label);	num_args++;
 	if (w->dialog.iconW != NULL &&
 	    XtHeight(w->dialog.labelW) <= XtHeight(w->dialog.iconW)) {
@@ -357,11 +360,11 @@ static void
 XawDialogGetValuesHook(Widget w, ArgList args, Cardinal *num_args)
 {
     Arg a[1];
-    String s;
+    char * s;
     DialogWidget src = (DialogWidget)w;
-    unsigned int i;
-  
-    for (i = 0; i < *num_args; i++)
+    Cardinal i;
+
+    for (i = 0; i < *num_args; i++) {
 	if (streq(args[i].name, XtNvalue)) {
 	    XtSetArg(a[0], XtNstring, &s);
 	    XtGetValues(src->dialog.valueW, a, 1);
@@ -372,6 +375,7 @@ XawDialogGetValuesHook(Widget w, ArgList args, Cardinal *num_args)
 	    XtGetValues(src->dialog.labelW, a, 1);
 	    *((char **)args[i].value) = s;
 	}
+    }
 }
 
 /*
