@@ -105,7 +105,7 @@ static XtResource resources[] = {
     sizeof(Pixel),
     offset(list.foreground),
     XtRString,
-    XtDefaultForeground
+    (XtPointer)XtDefaultForeground
   },
   {
     XtNcursor,
@@ -114,7 +114,7 @@ static XtResource resources[] = {
     sizeof(Cursor),
     offset(simple.cursor),
     XtRString,
-    "left_ptr"
+    (XtPointer)"left_ptr"
   },
   {
     XtNfont,
@@ -123,7 +123,7 @@ static XtResource resources[] = {
     sizeof(XFontStruct*),
     offset(list.font),
     XtRString,
-    XtDefaultFont
+    (XtPointer)XtDefaultFont
   },
   {
     XtNfontSet,
@@ -132,7 +132,7 @@ static XtResource resources[] = {
     sizeof(XFontSet),
     offset(list.fontset),
     XtRString,
-    XtDefaultFontSet
+    (XtPointer)XtDefaultFontSet
   },
   {
     XtNlist,
@@ -300,10 +300,15 @@ ListClassRec listClassRec = {
     NULL,				/* callback_private */
     defaultTranslations,		/* tm_table */
     XawListQueryGeometry,		/* query_geometry */
+    NULL,				/* display_accelerator */
+    NULL,				/* extension */
   },
   /* simple */
   {
     XtInheritChangeSensitive,		/* change_sensitive */
+#ifndef OLDXAW
+    NULL,
+#endif
   },
   /* list */
   {
@@ -319,11 +324,11 @@ WidgetClass listWidgetClass = (WidgetClass)&listClassRec;
 static void
 GetGCs(Widget w)
 {
-    XGCValues	values;
     ListWidget lw = (ListWidget)w;
-
-    values.foreground	= lw->list.foreground;
-    values.font		= lw->list.font->fid;
+    XGCValues	values = {
+	.foreground	= lw->list.foreground,
+	.font		= lw->list.font->fid
+    };
 
     if (lw->simple.international == True)
 	lw->list.normgc = XtAllocateGC(w, 0, GCForeground, &values, GCFont, 0);
@@ -353,7 +358,6 @@ GetGCs(Widget w)
 static void
 CalculatedValues(Widget w)
 {
-    int i, len;
     ListWidget lw = (ListWidget)w;
 
     /* If list is NULL then the list will just be the name of the widget */
@@ -369,15 +373,19 @@ CalculatedValues(Widget w)
 
     /* Get column width */
     if (LongestFree(lw)) {
+        int i;
+
 	lw->list.longest = 0; /* so it will accumulate real longest below */
 
 	for (i = 0 ; i < lw->list.nitems; i++) {
+	    int len;
+
 	    if (lw->simple.international == True)
 		len = XmbTextEscapement(lw->list.fontset, lw->list.list[i],
-					strlen(lw->list.list[i]));
+					(int)strlen(lw->list.list[i]));
 	    else
 		len = XTextWidth(lw->list.font, lw->list.list[i],
-				 strlen(lw->list.list[i]));
+				 (int)strlen(lw->list.list[i]));
 	    if (len > lw->list.longest)
 		lw->list.longest = len;
 	}
@@ -432,11 +440,12 @@ ResetList(Widget w, Bool changex, Bool changey)
 static void
 ChangeSize(Widget w, unsigned int width, unsigned int height)
 {
-    XtWidgetGeometry request, reply;
-
-    request.request_mode = CWWidth | CWHeight;
-    request.width = width;
-    request.height = height;
+    XtWidgetGeometry request = {
+	.request_mode = CWWidth | CWHeight,
+	.width = (Dimension)width,
+	.height = (Dimension)height
+    };
+    XtWidgetGeometry reply;
 
     switch (XtMakeGeometryRequest(w, &request, &reply)) {
 	case XtGeometryYes:
@@ -455,11 +464,11 @@ ChangeSize(Widget w, unsigned int width, unsigned int height)
 		    Layout(w, False, False, &request.width, &request.height);
 		    request.request_mode = CWWidth | CWHeight;
 		    XtMakeGeometryRequest(w, &request, &reply);
-		    /*FALLTROUGH*/
+		    /*FALLTHROUGH*/
 		default:
 		    break;
 	}
-	/*FALLTROUGH*/
+	/*FALLTHROUGH*/
 	default:
 	    break;
     }
@@ -467,7 +476,7 @@ ChangeSize(Widget w, unsigned int width, unsigned int height)
 
 /*ARGSUSED*/
 static void
-XawListInitialize(Widget temp1, Widget cnew, ArgList args, Cardinal *num_args)
+XawListInitialize(Widget temp1 _X_UNUSED, Widget cnew, ArgList args _X_UNUSED, Cardinal *num_args _X_UNUSED)
 {
     ListWidget lw = (ListWidget)cnew;
 
@@ -628,10 +637,10 @@ static void
 HighlightBackground(Widget w, int x, int y, GC gc)
 {
     ListWidget lw = (ListWidget)w;
-    Dimension width = lw->list.col_width;
-    Dimension height = lw->list.row_height;
-    Dimension frame_limited_width = XtWidth(w) - lw->list.internal_width - x;
-    Dimension frame_limited_height= XtHeight(w) - lw->list.internal_height - y;
+    Dimension width = (Dimension)lw->list.col_width;
+    Dimension height = (Dimension)lw->list.row_height;
+    Dimension frame_limited_width = (Dimension)(XtWidth(w) - lw->list.internal_width - x);
+    Dimension frame_limited_height= (Dimension)(XtHeight(w) - lw->list.internal_height - y);
 
     /* Clip the rectangle width and height to the edge of the drawable area */
     if  (width > frame_limited_width)
@@ -641,11 +650,11 @@ HighlightBackground(Widget w, int x, int y, GC gc)
 
     /* Clip the rectangle x and y to the edge of the drawable area */
     if (x < lw->list.internal_width) {
-	width = width - (lw->list.internal_width - x);
+	width = (Dimension)(width - (lw->list.internal_width - x));
 	x = lw->list.internal_width;
     }
     if (y < lw->list.internal_height) {
-      height = height - (lw->list.internal_height - y);
+      height = (Dimension)(height - (lw->list.internal_height - y));
 	y = lw->list.internal_height;
     }
 
@@ -668,14 +677,17 @@ HighlightBackground(Widget w, int x, int y, GC gc)
 static void
 ClipToShadowInteriorAndLongest(ListWidget lw, GC *gc_p, unsigned int x)
 {
-    XRectangle rect;
+    XRectangle rect = {
+	.x = (short)x,
+	.y = (short)lw->list.internal_height,
+	.height = (unsigned short)
+			(XtHeight(lw) - (lw->list.internal_height << 1)),
+	.width = (unsigned short)
+			(XtWidth(lw) - (unsigned)lw->list.internal_width - x),
+    };
 
-    rect.x = x;
-    rect.y = lw->list.internal_height;
-    rect.height = XtHeight(lw) - (lw->list.internal_height << 1);
-    rect.width = XtWidth(lw) - lw->list.internal_width - x;
     if (rect.width > lw->list.longest)
-	rect.width = lw->list.longest;
+	rect.width = (unsigned short)lw->list.longest;
 
     XSetClipRectangles(XtDisplay((Widget)lw), *gc_p, 0, 0, &rect, 1, YXBanded);
 }
@@ -683,7 +695,7 @@ ClipToShadowInteriorAndLongest(ListWidget lw, GC *gc_p, unsigned int x)
 static void
 PaintItemName(Widget w, int item)
 {
-    char *str;
+    _Xconst char *str;
     GC gc;
     int x, y, str_y;
     ListWidget lw = (ListWidget)w;
@@ -748,13 +760,13 @@ PaintItemName(Widget w, int item)
 
     str =  lw->list.list[item];	/* draw it */
 
-    ClipToShadowInteriorAndLongest(lw, &gc, x);
+    ClipToShadowInteriorAndLongest(lw, &gc, (unsigned)x);
 
     if (lw->simple.international == True)
 	XmbDrawString(XtDisplay(w), XtWindow(w), lw->list.fontset,
-		      gc, x, str_y, str, strlen(str));
+		      gc, x, str_y, str, (int)strlen(str));
     else
-	XDrawString(XtDisplay(w), XtWindow(w), gc, x, str_y, str, strlen(str));
+	XDrawString(XtDisplay(w), XtWindow(w), gc, x, str_y, str, (int)strlen(str));
 
     XSetClipMask(XtDisplay(w), gc, None);
 }
@@ -876,13 +888,13 @@ Layout(Widget w, Bool xfree, Bool yfree, Dimension *width, Dimension *height)
 	    /* this counts the same number
 	       of inter-column column_space 's as columns.  There should thus
 	       be a half column_space margin on each side of each column...*/
-	    width2 = lw->list.ncols * lw->list.col_width +
-		     (lw->list.internal_width << 1);
+	    width2 = (unsigned long)(lw->list.ncols * lw->list.col_width +
+		     (lw->list.internal_width << 1));
 	    change = True;
 	}
 	if (yfree) {
-	    height2 = lw->list.nrows * lw->list.row_height +
-		      (lw->list.internal_height << 1);
+	    height2 = (unsigned long)(lw->list.nrows * lw->list.row_height +
+		      (lw->list.internal_height << 1));
 	    change = True;
 	}
     }
@@ -902,10 +914,10 @@ Layout(Widget w, Bool xfree, Bool yfree, Dimension *width, Dimension *height)
 		|| (lw->list.ncols = wid / lw->list.col_width) <= 0)
 		lw->list.ncols = 1;
 	}
-	width2 = lw->list.ncols * lw->list.col_width
-	+ (lw->list.internal_width << 1);
-	height2 = (lw->list.nrows * lw->list.row_height)
-	+ (lw->list.internal_height << 1);
+	width2 = (unsigned long)((lw->list.ncols * lw->list.col_width)
+		  + (lw->list.internal_width << 1));
+	height2 = (unsigned long)((lw->list.nrows * lw->list.row_height)
+		   + (lw->list.internal_height << 1));
 	change = True;
     }
 
@@ -921,8 +933,8 @@ Layout(Widget w, Bool xfree, Bool yfree, Dimension *width, Dimension *height)
 	    lw->list.ncols = 1;
 	lw->list.nrows = ((lw->list.nitems - 1) / lw->list.ncols) + 1;
 	if (yfree) {
-	    height2 = lw->list.nrows * lw->list.row_height +
-		      (lw->list.internal_height << 1);
+	    height2 = (unsigned long)((lw->list.nrows * lw->list.row_height) +
+		      (lw->list.internal_height << 1));
 	    change = True;
 	}
     }
@@ -938,8 +950,8 @@ Layout(Widget w, Bool xfree, Bool yfree, Dimension *width, Dimension *height)
 	if (lw->list.nrows <= 0)
 	    lw->list.nrows = 1;
 	lw->list.ncols = ((lw->list.nitems - 1) / lw->list.nrows) + 1;
-	width2 = lw->list.ncols * lw->list.col_width  +
-		 (lw->list.internal_width << 1);
+	width2 = (unsigned long)((lw->list.ncols * lw->list.col_width) +
+		 (lw->list.internal_width << 1));
 	change = True;
     }
 
@@ -947,10 +959,10 @@ Layout(Widget w, Bool xfree, Bool yfree, Dimension *width, Dimension *height)
 	/*CONSTCOND*/
 	while (1) {
 	    lw->list.nrows = ((lw->list.nitems - 1) / lw->list.ncols) + 1;
-	    width2 = lw->list.ncols * lw->list.col_width +
-		     (lw->list.internal_width << 1);
-	    height2 = lw->list.nrows * lw->list.row_height +
-		      (lw->list.internal_height << 1);
+	    width2 = (unsigned long)((lw->list.ncols * lw->list.col_width) +
+		     (lw->list.internal_width << 1));
+	    height2 = (unsigned long)((lw->list.nrows * lw->list.row_height) +
+		      (lw->list.internal_height << 1));
 	    if (width2 >= MaxSize && height2 >= MaxSize)
 		break;
 	    if (height2 > MaxSize)
@@ -962,9 +974,9 @@ Layout(Widget w, Bool xfree, Bool yfree, Dimension *width, Dimension *height)
 	}
     }
     if (width2)
-	*width = width2;
+	*width = (Dimension)width2;
     if (height2)
-	*height = height2;
+	*height = (Dimension)height2;
 
     return (change);
 }
@@ -976,11 +988,10 @@ Layout(Widget w, Bool xfree, Bool yfree, Dimension *width, Dimension *height)
  * then the name of the item is also put in CUT_BUFFER0 */
 /*ARGSUSED*/
 static void
-Notify(Widget w, XEvent *event, String *params, Cardinal *num_params)
+Notify(Widget w, XEvent *event, String *params _X_UNUSED, Cardinal *num_params _X_UNUSED)
 {
     ListWidget lw = (ListWidget)w;
     int item, item_len;
-    XawListReturnStruct ret_value;
 
     /*
      * Find item and if out of range then unhighlight and return
@@ -1001,7 +1012,7 @@ Notify(Widget w, XEvent *event, String *params, Cardinal *num_params)
 	return;
     }
 
-    item_len = strlen(lw->list.list[item]);
+    item_len = (int)strlen(lw->list.list[item]);
 
     if (lw->list.paste)		/* if XtNpasteBuffer set then paste it */
 	XStoreBytes(XtDisplay(w), lw->list.list[item], item_len);
@@ -1012,10 +1023,14 @@ Notify(Widget w, XEvent *event, String *params, Cardinal *num_params)
     /*
      * Call Callback function
      */
-    ret_value.string = lw->list.list[item];
-    ret_value.list_index = item;
+    {
+	XawListReturnStruct ret_value = {
+	    .string = lw->list.list[item],
+	    .list_index = item
+	};
 
-    XtCallCallbacks(w, XtNcallback, (XtPointer)&ret_value);
+	XtCallCallbacks(w, XtNcallback, (XtPointer)&ret_value);
+    }
 }
 
 /* Unset() - Action
@@ -1023,7 +1038,7 @@ Notify(Widget w, XEvent *event, String *params, Cardinal *num_params)
  * unhighlights the current element */
 /*ARGSUSED*/
 static void
-Unset(Widget w, XEvent *event, String *params, Cardinal *num_params)
+Unset(Widget w, XEvent *event _X_UNUSED, String *params _X_UNUSED, Cardinal *num_params _X_UNUSED)
 {
     XawListUnhighlight(w);
 }
@@ -1033,7 +1048,7 @@ Unset(Widget w, XEvent *event, String *params, Cardinal *num_params)
  * Highlights the current element */
 /*ARGSUSED*/
 static void
-Set(Widget w, XEvent *event, String *params, Cardinal *num_params)
+Set(Widget w, XEvent *event, String *params _X_UNUSED, Cardinal *num_params _X_UNUSED)
 {
     int item;
     ListWidget lw = (ListWidget)w;
@@ -1053,7 +1068,7 @@ Set(Widget w, XEvent *event, String *params, Cardinal *num_params)
 /*ARGSUSED*/
 static Boolean
 XawListSetValues(Widget current, Widget request, Widget cnew,
-		 ArgList args, Cardinal *num_args)
+		 ArgList args _X_UNUSED, Cardinal *num_args _X_UNUSED)
 {
     ListWidget cl = (ListWidget)current;
     ListWidget rl = (ListWidget)request;
@@ -1143,7 +1158,7 @@ XawListSetValues(Widget current, Widget request, Widget cnew,
 	redraw = True;
     }
 
-    return (redraw);
+    return (Boolean)(redraw);
 }
 
 static void
@@ -1178,7 +1193,7 @@ XawListDestroy(Widget w)
  *	If nitems is <= 0 then the list needs to be NULL terminated
  */
 void
-XawListChange(Widget w, char **list, int nitems, int longest,
+XawListChange(Widget w, String *list, int nitems, int longest,
 #if NeedWidePrototypes
 	int resize_it
 #else
